@@ -20,6 +20,7 @@ __docformat__ = "restructuredtext"
 # import Zope3 interfaces
 
 # import local interfaces
+from ztfy.jqueryui import jquery_multiselect
 
 # import Zope3 packages
 from z3c.form import button, field
@@ -45,6 +46,7 @@ class RolesEditForm(DialogEditForm):
     legend = _("Define roles on current context")
 
     interfaces = ()
+    resources = (jquery_multiselect,)
 
     @property
     def fields(self):
